==> apache-plc4x-0.12.0-source-release.zip: apache-plc4x-0.12.0/plc4go/spi/model/DefaultPlcWriteRequestResult.go <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package model

import apiModel "github.com/apache/plc4x/plc4go/pkg/api/model"

var _ apiModel.PlcWriteRequestResult = &DefaultPlcWriteRequestResult{}

//go:generate go run ../../tools/plc4xgenerator/gen.go -type=DefaultPlcWriteRequestResult
type DefaultPlcWriteRequestResult struct {
	Request  apiModel.PlcWriteRequest
	Response apiModel.PlcWriteResponse
	Err      error
}

func NewDefaultPlcWriteRequestResult(Request apiModel.PlcWriteRequest, Response apiModel.PlcWriteResponse, Err error) apiModel.PlcWriteRequestResult {
	return &DefaultPlcWriteRequestResult{Request, Response, Err}
}

func (d *DefaultPlcWriteRequestResult) GetRequest() apiModel.PlcWriteRequest {
	return d.Request
}

func (d *DefaultPlcWriteRequestResult) GetResponse() apiModel.PlcWriteResponse {
	return d.Response
}

func (d *DefaultPlcWriteRequestResult) GetErr() error {
	return d.Err
}

==> apache-plc4x-0.13.1-source-release.zip: apache-plc4x-0.13.1/plc4go/spi/model/DefaultPlcWriteRequestResult.go <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package model

import apiModel "github.com/apache/plc4x/plc4go/pkg/api/model"

var _ apiModel.PlcWriteRequestResult = &DefaultPlcWriteRequestResult{}

//go:generate go tool plc4xGenerator -type=DefaultPlcWriteRequestResult
type DefaultPlcWriteRequestResult struct {
	Request  apiModel.PlcWriteRequest
	Response apiModel.PlcWriteResponse
	Err      error
}

func NewDefaultPlcWriteRequestResult(Request apiModel.PlcWriteRequest, Response apiModel.PlcWriteResponse, Err error) apiModel.PlcWriteRequestResult {
	return &DefaultPlcWriteRequestResult{Request, Response, Err}
}

func (d *DefaultPlcWriteRequestResult) GetRequest() apiModel.PlcWriteRequest {
	return d.Request
}

func (d *DefaultPlcWriteRequestResult) GetResponse() apiModel.PlcWriteResponse {
	return d.Response
}

func (d *DefaultPlcWriteRequestResult) GetErr() error {
	return d.Err
}
